about summary refs log tree commit diff
path: root/time
diff options
context:
space:
mode:
Diffstat (limited to 'time')
-rw-r--r--time/localtime.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/time/localtime.c b/time/localtime.c
index 8bf916fd6d..77d19ff5e7 100644
--- a/time/localtime.c
+++ b/time/localtime.c
@@ -18,7 +18,10 @@
 
 #include <time.h>
 
-/* The C Standard says that localtime and gmtime return the same pointer.  */
+/* C89 says that localtime and gmtime return the same pointer.
+   Although C99 and later relax this to let localtime and gmtime
+   return different pointers, POSIX and glibc currently follow C89's stricter
+   requirement even though this can cause naive programs to misbehave.  */
 struct tm _tmbuf;